@@ -33,13 +33,17 @@
 #include <stdlib.h>
 #include <string.h>
 
+#if HAVE_STROPTS_H
+#include <stropts.h>
+#endif
+
 /* Used by "error" function. */
 const char *program_name = "pseudotty";
 
 int
 main (int argc, char *argv[])
 {
-  int master, control;
+  int master, slave, control;
   char *name;
   fd_set read_set;
 
@@ -55,9 +59,31 @@ main (int argc, char *argv[])
   name = ptsname (master);
   if (!name)
     exit (1);
-
   error (0, 0, "%s", name);
 
+#ifdef HAVE_STROPTS_H
+  error (0, 0, "opening slave device");
+  slave = open (name, O_RDWR);
+  if (slave == -1)
+    exit (1);
+  if (!isatty (slave))
+    {
+      error (0, 0, "performing STREAMS ioctl's on slave");
+      if (isastream (slave))
+        {
+          if (ioctl (slave, I_PUSH, "ptem") < 0
+              || ioctl (slave, I_PUSH, "ldterm") < 0)
+            error (1, 0, "STREAMS ioctl's failed");
+        }
+    }
+  /* Don't close it because it just leads to an EOF read at the master end. */
+  /*
+  error (0, 0, "closing slave device");
+  close (slave);
+  error (0, 0, "...closed");
+  */
+#endif
+
   printf ("%s\n", name);
   if (fclose (stdout) != 0)
     error (1, 0, "error closing stdout: aborting");
